Linter

Trait Linter 

pub trait Linter: Send + Sync {
    type Language: Language;
    type Lint: Lint;

    // Required method
    fn lint(
        &self,
        input: &[PathBuf],
        deny: DenyLevel,
        compiler: &mut Compiler,
    ) -> Result<()>;
}
Trait representing a linter for a language supported by Foundry.

Required Associated Types

type Language: Language

The target language.

type Lint: Lint

The lint metadata type.

Required Methods

fn lint( &self, input: &[PathBuf], deny: DenyLevel, compiler: &mut Compiler, ) -> Result<()>

Runs all configured lints against an already parsed Solar compiler.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a> Linter for SolidityLinter<'a>

Source

type Language = SolcLanguage

Source

type Lint = SolLint